@@ -21,6 +21,7 @@ TWITTER_USERNAME = 'baranus1@mail.ru'
 TWITTER_PASSWORD = 'jcej9EIAQrrptDBy'
 TWITTER_NAME = 'Travis Djangov'
 TWITTER_SCREEN_NAME = '@travis_djangov'
+TWITTER_USER_ID = 2931210558
 
 VKONTAKTE_CLIENT_ID = 3430034
 VKONTAKTE_CLIENT_SECRET = 'b0FwzyKtO8QiQmgWQMTz'
@@ -95,16 +96,17 @@ class OAuthTokensModelTest(TestCase):
 
     def test_methods_access_tag(self):
 
-        user = UserCredentials.objects.all()[0]
+        user = UserCredentialsFactory(provider='vkontakte',
+                                      username=VKONTAKTE_USERNAME, password=VKONTAKTE_PASSWORD, additional=VKONTAKTE_ADDITIONAL)
         user.tags.add(Tag.objects.create(name='ads'))
 
         for i in range(30):
             AccessTokenFactory(provider='vkontakte')
-        access_token = AccessTokenFactory.create(provider='vkontakte', user_credentials=user)
+        access_token = AccessTokenFactory(provider='vkontakte', user_credentials=user)
 
         access_tokens = AccessToken.objects.filter_active_tokens_of_provider('vkontakte', tag='ads')
         self.assertEqual(access_tokens.count(), 1)
-        self.assertTrue(access_token in access_tokens)
+        self.assertEqual(access_token, access_tokens[0])
 
     def test_getting_token_by_tag(self):
 
@@ -151,7 +153,7 @@ class FacebookAccessTokenTest(TestCase):
 
     def assertFacebookToken(self, token):
         self.assertEqual(len(token), 4)
-        self.assertGreater(len(token['access_token']), 200)
+        self.assertGreater(len(token['access_token']), 160)
         self.assertGreaterEqual(token['expires_in'], 5000000)
         self.assertGreaterEqual(token['expires_at'], 1423930080.062079)
         self.assertEqual(token['scope'], FACEBOOK_SCOPE)
@@ -208,9 +210,10 @@ class FacebookAccessTokenTest(TestCase):
 
 class TwitterAccessTokenTest(TestCase):
 
-    def assertTwitterToken(self, token, access_token):
-        self.assertGreater(len(access_token), 30)
-        self.assertEqual(len(access_token.split(token.delimeter)), 2)
+    def assertTwitterToken(self, token_class, token):
+        self.assertGreater(len(token['access_token']), 90)
+        self.assertEqual(len(token['access_token'].split(token_class.delimeter)), 2)
+        self.assertEqual(int(token['user_id']), TWITTER_USER_ID)
 
     def test_twitter_oauth_access_token(self):
         settings_temp = dict(OAUTH_TOKENS_TWITTER_USERNAME=TWITTER_USERNAME,
@@ -348,11 +351,3 @@ class OdnoklassnikiAccessTokenTest(TestCase):
             response = OdnoklassnikiAuthRequest().authorized_request(url=req.form_action_domain)
             self.assertEqual(response.status_code, 200)
             self.assertEqual(response.content.count(ODNOKLASSNIKI_NAME), 2)
-
-
-class OAuthAccessTokenTest(VkontakteAccessTokenTest, FacebookAccessTokenTest, TwitterAccessTokenTest, OdnoklassnikiAccessTokenTest):
-    pass
-
-
-class OAuthTokensTest(OAuthTokensModelTest, OAuthAccessTokenTest):
-    pass
